bayespy.inference.vmp.nodes.beta.BetaMoments.add_converter
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaMoments.add_converter